xdoctest.docstr package
=======================

Submodules
----------

.. toctree::

   xdoctest.docstr.docscrape_google

Module contents
---------------

.. automodule:: xdoctest.docstr
    :members:
    :undoc-members:
    :show-inheritance:
